import re

from sohstationviewer.conf.constants import (WF_1ST, WF_2ND, WF_3RD)
"""
seisRE: Seismic data channels' regex:
First letter(Band Code): ABCDEFGHLMOPQRSTUV
Second letter (Instrument Code): GHLMN  (remove GM - Alissa)
Third letter (Orientation Code): ZNE123
=> to check if the channel is seismic data: if conf['seisRE'].match(chan):
"""

dbConf = {
    'dbpath': 'sohstationviewer/database/soh.db',
    'seisRE': re.compile(f'[{WF_1ST}][{WF_2ND}][{WF_3RD}]'),
    # key is last char of chan
    'seisLabel': {'1': 'NS', '2': 'EW', 'N': 'NS', 'E': 'EW', 'Z': 'V'},
    # +0.2:Y
    'multiColorDots': {
        'pattern': re.compile('^\+?\-?[0-9]+\.?[0-9]?:[RYGMWC_]'),  # noqa: W605,E501
        'instruction': (
            "Colors include: RYGMCW\n"
            "Ex: *:W  means everything with white color\n",
            "Ex: -1:_|0:R|2.3:Y|+2.3:G  means:\n"
            "   value <= -1  => not plot\n"
            "   value <= 0   => plot with R color\n"
            "   value <= 2.3 => plot with Y color\n"
            "   value > 2.3  => plot with G color")},
    'upDownDots': {
        'pattern': re.compile("^[01]:[WRYGMC]$"),
        'instruction': (
            "Colors include: RYGMCW\n"
            "Ex: 1:Y|0:R  means:\n"
            "   value == 1 => plot above center line with Y color\n"
            "   value == 0 => plot under center line with R color")},
    'linesDots': {
        'pattern': re.compile('^[LD]:[WRYGMC]$'),
        'instruction': (
            "Colors include: RYGMCW\n"
            "Ex: L:G|D:W  means\n"
            "   Lines are plotted with color G\n"
            "   Dots are plotted with color W\n"
            "If D is not defined, dots won't be displayed.\n"
            "If L is not defined, lines will be plotted with color G")}
}
